package sun.usagetracker;

import java.io.OutputStreamWriter;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.lang.reflect.InvocationTargetException;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.net.InetAddress;
import java.util.Date;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.util.Properties;
import java.io.File;
import jdk.internal.util.EnvUtils;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.concurrent.atomic.AtomicBoolean;

public final class UsageTrackerClient
{
    private static final Object LOCK;
    private static final String ORCL_UT_CONFIG_FILE_NAME = "usagetracker.properties";
    private static final String ORCL_UT_USAGE_DIR = ".oracle_jre_usage";
    private static final String ORCL_UT_PROPERTY_NAME = "com.oracle.usagetracker.";
    private static final String ORCL_UT_PROPERTY_RUN_SYNCHRONOUSLY = "com.oracle.usagetracker.run.synchronous";
    private static final String ORCL_UT_PROPERTY_CONFIG_FILE_NAME = "com.oracle.usagetracker.config.file";
    private static final String ORCL_UT_LOGTOFILE = "com.oracle.usagetracker.logToFile";
    private static final String ORCL_UT_LOGFILEMAXSIZE = "com.oracle.usagetracker.logFileMaxSize";
    private static final String ORCL_UT_LOGTOUDP = "com.oracle.usagetracker.logToUDP";
    private static final String ORCL_UT_RECORD_MAXSIZE = "com.oracle.usagetracker.maxSize";
    private static final String ORCL_UT_RECORD_MAXFIELDSIZE = "com.oracle.usagetracker.maxFieldSize";
    private static final String ORCL_UT_SEND_TRUNCATED = "com.oracle.usagetracker.sendTruncatedRecords";
    private static final String ORCL_UT_TRACK_LAST_USAGE = "com.oracle.usagetracker.track.last.usage";
    private static final String ORCL_UT_VERBOSE = "com.oracle.usagetracker.verbose";
    private static final String ORCL_UT_DEBUG = "com.oracle.usagetracker.debug";
    private static final String ORCL_UT_ADDITIONALPROPERTIES = "com.oracle.usagetracker.additionalProperties";
    private static final String ORCL_UT_SEPARATOR = "com.oracle.usagetracker.separator";
    private static final String ORCL_UT_QUOTE = "com.oracle.usagetracker.quote";
    private static final String ORCL_UT_QUOTE_INNER = "com.oracle.usagetracker.innerQuote";
    private static final String DISABLE_LAST_USAGE_PROP_NAME = "jdk.disableLastUsageTracking";
    private static final String DEFAULT_SEP = ",";
    private static final String DEFAULT_QUOTE = "\"";
    private static final String DEFAULT_QUOTE_INNER = "'";
    private static final AtomicBoolean isFirstRun;
    private static final String javaHome;
    private static final String userHomeKeyword = "${user.home}";
    private static String separator;
    private static String quote;
    private static String innerQuote;
    private static boolean enabled;
    private static boolean verbose;
    private static boolean debug;
    private static boolean trackTime;
    private static String[] additionalProperties;
    private static String fullLogFilename;
    private static long logFileMaxSize;
    private static int maxSize;
    private static int maxFieldSize;
    private static boolean sendTruncated;
    private static String datagramHost;
    private static int datagramPort;
    private static String staticMessage;
    private static boolean staticMessageIsTruncated;
    
    private static String getPropertyPrivileged(String s) {
        return getPropertyPrivileged(s, null);
    }
    
    private static String getPropertyPrivileged(final String s, final String s2) {
        return (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return System.getProperty(s, s2);
            }
        });
    }
    
    private static String getEnvPrivileged(final String s) {
        return (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return EnvUtils.getEnvVar(s);
            }
        });
    }
    
    private static boolean initTrackTime() {
        String propertyPrivileged = getPropertyPrivileged("jdk.disableLastUsageTracking");
        if (propertyPrivileged == null) {
            String propertyPrivileged2 = getPropertyPrivileged("os.name");
            if (propertyPrivileged2 != null) {
                String lowerCase = propertyPrivileged2.toLowerCase();
                if (lowerCase.startsWith("sunos") || lowerCase.startsWith("linux")) {
                    return false;
                }
            }
            return true;
        }
        else {
            return !propertyPrivileged.isEmpty() && !propertyPrivileged.equalsIgnoreCase("true");
        }
    }
    
    private static File getConfigFilePrivileged() {
        File file = null;
        String[] array;
        for (String s : array = new String[] { getPropertyPrivileged("com.oracle.usagetracker.config.file"), getOSSpecificConfigFilePath(), UsageTrackerClient.javaHome + File.separator + "lib" + File.separator + "management" + File.separator + "usagetracker.properties" }) {
            if (s != null) {
                file = (File)AccessController.doPrivileged(new PrivilegedAction<File>() {
                    @Override
                    public File run() {
                        File file = new File(s);
                        return file.exists() ? file : null;
                    }
                });
                if (file != null) {
                    break;
                }
            }
        }
        return file;
    }
    
    private static String getOSSpecificConfigFilePath() {
        String propertyPrivileged = getPropertyPrivileged("os.name");
        if (propertyPrivileged != null) {
            if (propertyPrivileged.toLowerCase().startsWith("sunos")) {
                return "/etc/oracle/java/usagetracker.properties";
            }
            if (propertyPrivileged.toLowerCase().startsWith("mac")) {
                return "/Library/Application Support/Oracle/Java/usagetracker.properties";
            }
            if (propertyPrivileged.toLowerCase().startsWith("win")) {
                String envPrivileged = getEnvPrivileged("ProgramFiles");
                return (envPrivileged == null) ? null : (envPrivileged + "\\Java\\conf\\" + "usagetracker.properties");
            }
            if (propertyPrivileged.toLowerCase().startsWith("linux")) {
                return "/etc/oracle/java/usagetracker.properties";
            }
        }
        return null;
    }
    
    private String getFullLogFilename(Properties properties) {
        String pathname = properties.getProperty("com.oracle.usagetracker.logToFile", "");
        if (pathname.isEmpty()) {
            return null;
        }
        if (pathname.startsWith("${user.home}")) {
            if (pathname.length() > "${user.home}".length()) {
                pathname = getPropertyPrivileged("user.home") + pathname.substring("${user.home}".length());
            }
            else {
                this.printVerbose("UsageTracker: blank filename after user.home.");
                return null;
            }
        }
        else if (!new File(pathname).isAbsolute()) {
            this.printVerbose("UsageTracker: relative path disallowed.");
            return null;
        }
        return pathname;
    }
    
    private long getPropertyValueLong(Properties properties, String s) {
        String property = properties.getProperty(s, "");
        if (!property.isEmpty()) {
            try {
                return Long.parseLong(property);
            }
            catch (NumberFormatException ex) {
                this.printVerbose("UsageTracker: bad value: " + s);
            }
        }
        return -1L;
    }
    
    private boolean getPropertyValueBoolean(Properties properties, String key, boolean b) {
        String property = properties.getProperty(key, "");
        if (!property.isEmpty()) {
            return Boolean.parseBoolean(property);
        }
        return b;
    }
    
    private String[] getAdditionalProperties(Properties properties) {
        String property = properties.getProperty("com.oracle.usagetracker.additionalProperties", "");
        return property.isEmpty() ? new String[0] : property.split(",");
    }
    
    private String parseDatagramHost(String s) {
        if (s != null) {
            int index = s.indexOf(58);
            if (index > 0 && index < s.length() - 1) {
                return s.substring(0, index);
            }
            this.printVerbose("UsageTracker: bad UDP details.");
        }
        return null;
    }
    
    private int parseDatagramPort(String s) {
        if (s != null) {
            int index = s.indexOf(58);
            try {
                return Integer.parseInt(s.substring(index + 1));
            }
            catch (Exception ex) {
                this.printVerbose("UsageTracker: bad UDP port.");
            }
        }
        return 0;
    }
    
    private void printVerbose(String x) {
        if (UsageTrackerClient.verbose) {
            System.err.println(x);
        }
    }
    
    private void printDebug(String x) {
        if (UsageTrackerClient.debug) {
            System.err.println(x);
        }
    }
    
    private void printDebugStackTrace(Throwable t) {
        if (UsageTrackerClient.debug) {
            t.printStackTrace();
        }
    }
    
    public UsageTrackerClient() {
    }
    
    private void setupAndTimestamp(long n) {
        if (UsageTrackerClient.isFirstRun.compareAndSet(true, false)) {
            File configFilePrivileged = getConfigFilePrivileged();
            if (configFilePrivileged != null) {
                this.setup(configFilePrivileged);
            }
            if (UsageTrackerClient.trackTime) {
                this.registerUsage(n);
            }
        }
    }
    
    public void run(final String str, final String str2) {
        this.printDebug("UsageTracker.run: " + str + ", javaCommand: " + str2);
        try {
            AccessController.doPrivileged(new PrivilegedAction<Void>() {
                @Override
                public Void run() {
                    long currentTimeMillis = System.currentTimeMillis();
                    int boolean1 = Boolean.parseBoolean(System.getProperty("com.oracle.usagetracker.run.synchronous", "true"));
                    if (!(boolean1 == 0)) {
                        UsageTrackerClient.access$000(UsageTrackerClient.this, currentTimeMillis);
                        UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: running synchronous.");
                    }
                    if (UsageTrackerClient.enabled || boolean1 == 0) {
                        UsageTrackerClient.UsageTrackerRunnable task = new UsageTrackerClient.UsageTrackerRunnable(str, str2, currentTimeMillis, (boolean)(boolean1 == 0));
                        ThreadGroup group;
                        for (group = Thread.currentThread().getThreadGroup(); group.getParent() != null; group = group.getParent()) {}
                        Thread o = new Thread(group, task, "UsageTracker");
                        o.setDaemon(true);
                        o.start();
                    }
                    return null;
                }
            });
        }
        catch (Throwable t) {
            this.printVerbose("UsageTracker: error in starting thread.");
            this.printDebugStackTrace(t);
        }
    }
    
    private void setup(File file) {
        Properties properties = new Properties();
        if (file != null) {
            try (final FileInputStream in = new FileInputStream(file);
                 final BufferedInputStream inStream = new BufferedInputStream(in)) {
                properties.load(inStream);
            }
            catch (Exception ex) {
                properties.clear();
            }
        }
        UsageTrackerClient.verbose = this.getPropertyValueBoolean(properties, "com.oracle.usagetracker.verbose", false);
        UsageTrackerClient.debug = this.getPropertyValueBoolean(properties, "com.oracle.usagetracker.debug", false);
        UsageTrackerClient.separator = properties.getProperty("com.oracle.usagetracker.separator", ",");
        UsageTrackerClient.quote = properties.getProperty("com.oracle.usagetracker.quote", "\"");
        UsageTrackerClient.innerQuote = properties.getProperty("com.oracle.usagetracker.innerQuote", "'");
        UsageTrackerClient.fullLogFilename = this.getFullLogFilename(properties);
        UsageTrackerClient.logFileMaxSize = this.getPropertyValueLong(properties, "com.oracle.usagetracker.logFileMaxSize");
        UsageTrackerClient.maxSize = (int)this.getPropertyValueLong(properties, "com.oracle.usagetracker.maxSize");
        UsageTrackerClient.maxFieldSize = (int)this.getPropertyValueLong(properties, "com.oracle.usagetracker.maxFieldSize");
        UsageTrackerClient.sendTruncated = this.getPropertyValueBoolean(properties, "com.oracle.usagetracker.sendTruncatedRecords", true);
        UsageTrackerClient.additionalProperties = this.getAdditionalProperties(properties);
        String property = properties.getProperty("com.oracle.usagetracker.logToUDP");
        UsageTrackerClient.datagramHost = this.parseDatagramHost(property);
        UsageTrackerClient.datagramPort = this.parseDatagramPort(property);
        UsageTrackerClient.enabled = (UsageTrackerClient.fullLogFilename != null || (UsageTrackerClient.datagramHost != null && UsageTrackerClient.datagramPort > 0));
        if (UsageTrackerClient.trackTime) {
            UsageTrackerClient.trackTime = this.getPropertyValueBoolean(properties, "com.oracle.usagetracker.track.last.usage", true);
        }
    }
    
    private void registerUsage(long lng) {
        try {
            String canonicalPath = new File(System.getProperty("java.home")).getCanonicalPath();
            String propertyPrivileged = getPropertyPrivileged("os.name");
            File file = null;
            if (propertyPrivileged.toLowerCase().startsWith("win")) {
                String envPrivileged = getEnvPrivileged("ProgramData");
                if (envPrivileged != null) {
                    file = new File(envPrivileged + File.separator + "Oracle" + File.separator + "Java" + File.separator + ".oracle_jre_usage", this.getPathHash(canonicalPath) + ".timestamp");
                    if (!file.exists()) {
                        if (!file.getParentFile().exists()) {
                            if (file.getParentFile().mkdirs()) {
                                File obj = new File(getEnvPrivileged("SYSTEMROOT") + File.separator + "system32" + File.separator + "icacls.exe");
                                if (obj.exists()) {
                                    Runtime.getRuntime().exec(obj + " " + file.getParentFile() + " /grant \"everyone\":(OI)(CI)M");
                                }
                            }
                            else {
                                file = null;
                            }
                        }
                        if (file != null) {
                            file.createNewFile();
                        }
                    }
                }
            }
            else {
                String property = System.getProperty("user.home");
                if (property != null) {
                    file = new File(property + File.separator + ".oracle_jre_usage", this.getPathHash(canonicalPath) + ".timestamp");
                    if (!file.exists()) {
                        if (!file.getParentFile().exists()) {
                            file.getParentFile().mkdirs();
                        }
                        file.createNewFile();
                    }
                }
            }
            if (file != null) {
                try (final Object o = new FileOutputStream(file)) {
                    o.write((canonicalPath + System.lineSeparator() + lng + System.lineSeparator()).getBytes("UTF-8"));
                }
                catch (IOException ex) {
                    this.printDebugStackTrace(ex);
                }
            }
        }
        catch (IOException ex2) {
            this.printDebugStackTrace(ex2);
        }
    }
    
    private String getPathHash(String s) {
        long i = 0L;
        for (int j = 0; j < s.length(); ++j) {
            i = 31L * i + (long)s.charAt(j);
        }
        return Long.toHexString(i);
    }
    
    static void access$000(UsageTrackerClient usageTrackerClient, long n) {
        usageTrackerClient.setupAndTimestamp(n);
    }
    
    static void access$100(UsageTrackerClient usageTrackerClient, String s) {
        usageTrackerClient.printVerbose(s);
    }
    
    static void access$300(UsageTrackerClient usageTrackerClient, String s) {
        usageTrackerClient.printDebug(s);
    }
    
    static String access$1100(String s) {
        return getPropertyPrivileged(s);
    }
    
    static void access$1800(UsageTrackerClient usageTrackerClient, Throwable t) {
        usageTrackerClient.printDebugStackTrace(t);
    }
    
    static {
        LOCK = new Object();
        isFirstRun = new AtomicBoolean(true);
        javaHome = getPropertyPrivileged("java.home");
        UsageTrackerClient.trackTime = initTrackTime();
    }
    
    class UsageTrackerRunnable implements Runnable
    {
        private String callerName;
        private String javaCommand;
        private long timestamp;
        private boolean runAsync;
        private boolean truncated;
        
        UsageTrackerRunnable(String callerName, String s, long timestamp, boolean runAsync) {
            this.callerName = callerName;
            this.javaCommand = ((s != null) ? s : "");
            this.timestamp = timestamp;
            this.runAsync = runAsync;
        }
        
        private String limitString(String substring, int n) {
            if (n > 0 && substring.length() >= n) {
                UsageTrackerClient.access$300(UsageTrackerClient.this, "UsgeTracker: limitString truncating: max=" + n + " length=" + substring.length() + " String: " + substring);
                this.truncated = true;
                substring = substring.substring(0, n);
                return substring;
            }
            return substring;
        }
        
        private String buildMessage(String s, String limitString, long date) {
            limitString = this.limitString(limitString, UsageTrackerClient.maxFieldSize);
            if (this.truncated && !UsageTrackerClient.sendTruncated) {
                return null;
            }
            StringBuilder sb = new StringBuilder();
            this.appendWithQuotes(sb, s);
            sb.append(UsageTrackerClient.separator);
            this.appendWithQuotes(sb, new Date(date).toString());
            sb.append(UsageTrackerClient.separator);
            String string = "0";
            try {
                string = InetAddress.getLocalHost().toString();
            }
            catch (Throwable t) {}
            this.appendWithQuotes(sb, string);
            sb.append(UsageTrackerClient.separator);
            this.appendWithQuotes(sb, limitString);
            sb.append(UsageTrackerClient.separator);
            sb.append(this.getRuntimeDetails());
            sb.append("\n");
            String limitString2 = this.limitString(sb.toString(), UsageTrackerClient.maxSize);
            if (this.truncated && !UsageTrackerClient.sendTruncated) {
                UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: length limit exceeded.");
                return null;
            }
            return limitString2;
        }
        
        private String getRuntimeDetails() {
            synchronized (UsageTrackerClient.LOCK) {
                if (UsageTrackerClient.staticMessage == null) {
                    StringBuilder sb = new StringBuilder();
                    int truncated = this.truncated;
                    this.truncated = false;
                    this.appendWithQuotes(sb, UsageTrackerClient.javaHome);
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("java.version"));
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("java.vm.version"));
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("java.vendor"));
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("java.vm.vendor"));
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("os.name"));
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("os.arch"));
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("os.version"));
                    sb.append(UsageTrackerClient.separator);
                    List<String> inputArguments = this.getInputArguments();
                    StringBuilder sb2 = new StringBuilder();
                    Iterator<Object> iterator = inputArguments.iterator();
                    while (iterator.hasNext()) {
                        sb2.append(this.addQuotesFor((String)iterator.next(), " ", UsageTrackerClient.innerQuote));
                        sb2.append(' ');
                    }
                    this.appendWithQuotes(sb, sb2.toString());
                    sb.append(UsageTrackerClient.separator);
                    this.appendWithQuotes(sb, UsageTrackerClient.access$1100("java.class.path"));
                    sb.append(UsageTrackerClient.separator);
                    StringBuilder o = new StringBuilder();
                    for (String s : UsageTrackerClient.additionalProperties) {
                        o.append(s.trim());
                        o.append("=");
                        o.append(this.addQuotesFor(UsageTrackerClient.access$1100(s.trim()), " ", UsageTrackerClient.innerQuote));
                        o.append(" ");
                    }
                    this.appendWithQuotes(sb, o.toString());
                    UsageTrackerClient.staticMessage = sb.toString();
                    UsageTrackerClient.staticMessageIsTruncated = this.truncated;
                    this.truncated = (truncated | (UsageTrackerClient.staticMessageIsTruncated ? 1 : 0));
                }
                else {
                    this.truncated |= UsageTrackerClient.staticMessageIsTruncated;
                }
                return UsageTrackerClient.staticMessage;
            }
        }
        
        private void appendWithQuotes(StringBuilder sb, String str) {
            sb.append(UsageTrackerClient.quote);
            str = this.limitString(str, UsageTrackerClient.maxFieldSize);
            str = str.replace(UsageTrackerClient.quote, UsageTrackerClient.quote + UsageTrackerClient.quote);
            if (!str.isEmpty()) {
                sb.append(str);
            }
            else {
                sb.append(" ");
            }
            sb.append(UsageTrackerClient.quote);
        }
        
        private String addQuotesFor(String str, String str2, String str3) {
            if (str == null) {
                return str;
            }
            str = str.replace(str3, str3 + str3);
            if (str.indexOf(str2) >= 0) {
                str = str3 + str + str3;
                return str;
            }
            return str;
        }
        
        private List<String> getInputArguments() {
            return (List)AccessController.doPrivileged(new PrivilegedAction<List<String>>() {
                @Override
                public List<String> run() {
                    try {
                        return (List)Class.forName("java.lang.management.RuntimeMXBean", true, null).getMethod("getInputArguments", (Class<?>[])null).invoke(Class.forName("java.lang.management.ManagementFactory", true, null).getMethod("getRuntimeMXBean", (Class<?>[])null).invoke(null, (Object[])null), (Object[])null);
                    }
                    catch (ClassNotFoundException ex) {
                        return Collections.singletonList("n/a");
                    }
                    catch (NoSuchMethodException detailMessage) {
                        throw new AssertionError(detailMessage);
                    }
                    catch (IllegalAccessException detailMessage2) {
                        throw new AssertionError(detailMessage2);
                    }
                    catch (InvocationTargetException ex2) {
                        throw new AssertionError(ex2.getCause());
                    }
                }
            });
        }
        
        private void sendDatagram(String s) {
            UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: sendDatagram");
            try (final DatagramSocket datagramSocket = new DatagramSocket()) {
                byte[] bytes = s.getBytes("UTF-8");
                if (bytes.length > datagramSocket.getSendBufferSize()) {
                    UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: message truncated for Datagram.");
                }
                UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: host=" + UsageTrackerClient.datagramHost + ", port=" + UsageTrackerClient.datagramPort);
                UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: SendBufferSize = " + datagramSocket.getSendBufferSize());
                UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: packet length  = " + bytes.length);
                DatagramPacket p = new DatagramPacket(bytes, (bytes.length > datagramSocket.getSendBufferSize()) ? datagramSocket.getSendBufferSize() : bytes.length, InetAddress.getByName(UsageTrackerClient.datagramHost), UsageTrackerClient.datagramPort);
                datagramSocket.send(p);
                UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: done sending to UDP.");
                UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: sent size = " + p.getLength());
            }
            catch (Throwable obj) {
                UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: error in sendDatagram: " + obj);
                UsageTrackerClient.access$1800(UsageTrackerClient.this, obj);
            }
        }
        
        private void sendToFile(String str) {
            UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: sendToFile");
            File file = new File(UsageTrackerClient.fullLogFilename);
            if (UsageTrackerClient.logFileMaxSize >= 0L && file.length() >= UsageTrackerClient.logFileMaxSize) {
                UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: log file size exceeds maximum.");
                return;
            }
            synchronized (UsageTrackerClient.LOCK) {
                try (final FileOutputStream out = new FileOutputStream(file, true);
                     final OutputStreamWriter outputStreamWriter = new OutputStreamWriter(out, "UTF-8")) {
                    outputStreamWriter.write(str, 0, str.length());
                    UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: done sending to file.");
                    UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTracker: " + UsageTrackerClient.fullLogFilename);
                }
                catch (Throwable t5) {
                    UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: error in sending to file.");
                    UsageTrackerClient.access$1800(UsageTrackerClient.this, t5);
                }
            }
            return;
        }
        
        @Override
        public void run() {
            if (this.runAsync) {
                UsageTrackerClient.access$000(UsageTrackerClient.this, this.timestamp);
                UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: running asynchronous.");
            }
            if (UsageTrackerClient.enabled) {
                UsageTrackerClient.access$300(UsageTrackerClient.this, "UsageTrackerRunnable.run: " + this.callerName + ", javaCommand: " + this.javaCommand);
                String buildMessage = this.buildMessage(this.callerName, this.javaCommand, this.timestamp);
                if (buildMessage != null) {
                    if (UsageTrackerClient.datagramHost != null && UsageTrackerClient.datagramPort > 0) {
                        this.sendDatagram(buildMessage);
                    }
                    if (UsageTrackerClient.fullLogFilename != null) {
                        this.sendToFile(buildMessage);
                    }
                }
                else {
                    UsageTrackerClient.access$100(UsageTrackerClient.this, "UsageTracker: length limit exceeded.");
                }
            }
        }
    }
}
